@@ -1,16 +1,19 @@
 # The contents of this file is free and unencumbered software released into the
 # public domain. For more information, please refer to <http://unlicense.org/>
-from anilistWrapPY.errors.types import AniListError
-from anilistWrapPY.errors.ex_class import AniListException
-from anilistWrapPY.Character.types import AniListCharacter
-from anilistWrapPY.Character.graphql import character_query
+import json
+
 import httpx
 
+from anilistWrapPY.Character.graphql import character_query
+from anilistWrapPY.Character.types import AniListCharacter, ani_list_character_from_dict
+from anilistWrapPY.errors import ani_list_error_from_dict
+from anilistWrapPY.errors.ex_class import AniListException
+
 
 def GetCharacter(search: str, baseUrl: str) -> AniListCharacter:
     variables = {"search": search}
     r = (httpx.post(baseUrl, json={"query": character_query, "variables": variables})).json()
     try:
-        return AniListCharacter(**r)
-    except AniListException:
-        return AniListError(**r)
\ No newline at end of file
+        return ani_list_character_from_dict(r)
+    except json.JSONDecodeError:
+        raise AniListException("{]".format(ani_list_error_from_dict(r)))
